@@ -1,5 +1,5 @@
 ///
-// Copyright (C) 2002, 2003, Fredrik Arnerup & Rasmus Kaj, See COPYING
+// Copyright (C) 2002 - 2004, Fredrik Arnerup & Rasmus Kaj, See COPYING
 ///
 #include "docview.h"
 
@@ -92,11 +92,6 @@ void DocumentView::delete_page() {
   }
 }
 
-void DocumentView::undo() { // if(document) document->undo(); 
-}
-  void DocumentView::redo() { //if(document) document->redo(); 
-}
-
 Page *DocumentView::get_page() {
   if(document) {
     Page *page = document->get_page(current_page_num);
@@ -186,10 +181,13 @@ DocumentView::DocumentView(DocMeta d)
   colormap->alloc_color(gray);
   colormap->alloc_color(red);
   zoom_factor = 0.5;
-
-  resolution = 72; //ppi
-  if(config.ScreenResolution.values.size())
-    resolution = config.ScreenResolution.values.front();
+  
+  Glib::RefPtr<Gdk::Screen> screen =
+    Gdk::Display::get_default()->get_default_screen();
+  float xresolution = screen->get_width() / (screen->get_width_mm() / 25.4);
+  float yresolution = screen->get_height() / (screen->get_height_mm() / 25.4);
+  resolution = (xresolution + yresolution) / 2;  // average :-)
+  verbose << "Screen resolution: " << resolution << " dpi" << std::endl;
 
   set_document(d);
   reshaping = moving = false;
